@@ -4,13 +4,15 @@ import Network.QUIC (StreamId)
 
 import Imports
 
-data H3StreamType = H3ControlStreams
-                  | H3PushStreams
-                  | QPACKEncoderStream
-                  | QPACKDecoderStream
-                  | H3StreamTypeUnknown Int64
-                  deriving (Eq, Show)
+data H3StreamType
+    = H3ControlStreams
+    | H3PushStreams
+    | QPACKEncoderStream
+    | QPACKDecoderStream
+    | H3StreamTypeUnknown Int64
+    deriving (Eq, Show)
 
+{- FOURMOLU_DISABLE -}
 fromH3StreamType :: H3StreamType -> Int64
 fromH3StreamType H3ControlStreams        = 0x00
 fromH3StreamType H3PushStreams           = 0x01
@@ -23,14 +25,15 @@ toH3StreamType 0x00 = H3ControlStreams
 toH3StreamType 0x01 = H3PushStreams
 toH3StreamType 0x02 = QPACKEncoderStream
 toH3StreamType 0x03 = QPACKDecoderStream
-toH3StreamType    i = H3StreamTypeUnknown i
+toH3StreamType i    = H3StreamTypeUnknown i
+{- FOURMOLU_ENABLE -}
 
-clientControlStream,clientEncoderStream,clientDecoderStream :: StreamId
+clientControlStream, clientEncoderStream, clientDecoderStream :: StreamId
 clientControlStream = 2
 clientEncoderStream = 6
 clientDecoderStream = 10
 
-serverControlStream,serverEncoderStream,serverDecoderStream :: StreamId
+serverControlStream, serverEncoderStream, serverDecoderStream :: StreamId
 serverControlStream = 3
 serverEncoderStream = 7
 serverDecoderStream = 11
